name: имя пакета (должно совпадать с названием корневой директории)
version: версия - позволяет корректно управлять зависимостями
url: URL пакета, например ссылка на GitHub (необязательный параметр)
author: автор пакета
author_email: почта автора пакета
description: краткое описание пакета
long_description: полное описание из файла README.md
packages: список вложенных пакетов, которые необходимо включить, тут поможет find_packages()
install_requires: указываются зависимости - библиотеки, которые нужны для работы данного пакета. Установятся автоматически до установки нашего пакета